# Ververser Example 2: Host a Separate Folder

In case you want to have your game content stored in a different folder 
than the folder that contains the logic for booting up the application, 
you can simply pass a path to ververser, specifying the folder contains your content. 
This is not really recommended though, in most cases it would just add additional boilerplate.

